/* Generated automatically by the program `genattr-common'
   from the machine description file `md'.  */

#ifndef GCC_INSN_ATTR_COMMON_H
#define GCC_INSN_ATTR_COMMON_H

enum attr_type {TYPE_ALU, TYPE_ST, TYPE_LD, TYPE_CONTROL, TYPE_MULTI, TYPE_FPU};
enum attr_insn_support {INSN_SUPPORT_CLASS1, INSN_SUPPORT_SEXT, INSN_SUPPORT_SFIMM, INSN_SUPPORT_SHFTIMM, INSN_SUPPORT_ROR, INSN_SUPPORT_RORI};
#define INSN_SCHEDULING
#define DELAY_SLOTS 1

#endif /* GCC_INSN_ATTR_COMMON_H */
