/* Generated automatically. */
static const char configuration_arguments[] = "/build/or1k-elf-gcc/src/gcc-15.2.0/configure --target=or1k-elf --prefix=/usr --with-sysroot=/usr/or1k-elf --with-native-system-header-dir=/include --libexecdir=/usr/lib --enable-languages=c,c++ --enable-threads=single --enable-plugins --enable-multilib --enable-libgcc --disable-libgomp --disable-libquadmath --disable-libffi --disable-libssp --disable-libmudflap --disable-decimal-float --disable-libstdcxx-pch --disable-nls --disable-shared --disable-tls --with-newlib --with-gnu-as --with-gnu-ld --with-system-zlib --with-headers=/usr/or1k-elf/include --with-python-dir=share/gcc-or1k-elf --with-gmp --with-mpfr --with-mpc --with-isl --with-libelf --enable-gnu-indirect-function --with-pkgversion='Arch Linux Repositories' --with-bugurl=https://gitlab.archlinux.org/archlinux/packaging/packages/or1k-elf-gcc/-/issues";
static const char thread_model[] = "single";

static const struct {
  const char *name, *value;
} configure_default_options[] = { { NULL, NULL} };
